

# Github Contribution Graph Manager (gcgman)
A python script to write words into your github contribution graph. Chosen word has a length limit
of 8.

Currently supported letters : 
A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, R, S, T, U, V, Y, Z, X, W, Q, space

## Usage
`gcgman <WORD> [OPTION...]`


## TODO

### Update README

### Add Contribution Page
